package jalview.renderer;

import jalview.analysis.Conservation;
import jalview.datamodel.AnnotatedCollectionI;
import jalview.datamodel.ProfilesI;
import jalview.datamodel.SequenceCollectionI;
import jalview.datamodel.SequenceI;
import jalview.schemes.ColourSchemeI;

import java.awt.Color;
import java.util.Map;

public interface ResidueShaderI
{

  public abstract void setConsensus(ProfilesI cons);

  public abstract boolean conservationApplied();

  public abstract void setConservationApplied(boolean conservationApplied);

  public abstract void setConservation(Conservation cons);

  public abstract void alignmentChanged(AnnotatedCollectionI alignment,
          Map<SequenceI, SequenceCollectionI> hiddenReps);

  /**
   * Sets the percentage consensus threshold value, and whether gaps are ignored
   * in percentage identity calculation
   * 
   * @param consensusThreshold
   * @param ignoreGaps
   */
  public abstract void setThreshold(int consensusThreshold,
          boolean ignoreGaps);

  public abstract void setConservationInc(int i);

  public abstract int getConservationInc();

  /**
   * Get the percentage threshold for this colour scheme
   * 
   * @return Returns the percentage threshold
   */
  public abstract int getThreshold();

  /**
   * Returns the possibly context dependent colour for the given symbol at the
   * aligned position in the given sequence. For example, the colour may depend
   * on the symbol's relationship to the consensus residue for the column.
   * 
   * @param symbol
   * @param position
   * @param seq
   * @return
   */
  public abstract Color findColour(char symbol, int position,
          SequenceI seq);

  public abstract ColourSchemeI getColourScheme();

  public abstract void setColourScheme(ColourSchemeI cs);

}